# **Open**
**Opensource Python**

Versão do Pyhton:
- 3.9.6

Link de integração:

[![Build Status](https://travis-ci.com/cleysoncassio/Open.svg?branch=master)](https://travis-ci.com/cleysoncassio/Open)

[![Updates](https://pyup.io/repos/github/cleysoncassio/Open/shield.svg)](https://pyup.io/repos/github/cleysoncassio/Open/)

[![Python 3](https://pyup.io/repos/github/cleysoncassio/Open/python-3-shield.svg)](https://pyup.io/repos/github/cleysoncassio/Open/)

Upload do projeto no Pypi:

[Pypi](https://test.pypi.org/project/source/0.1/)